##  Read-Only Fields
Certain fields are read-only and cannot be modified through the import process. These fields are automatically generated by SAP LeanIX and cannot be edited in the workspace. Changes to these fields in the spreadsheet will not affect their values in the fact sheet.
The current read-only fields are:
  * updatedAt
  * createdAt
  * id
  * type
  * completion
  * displayName


An exception is the id field: if this field is removed from the spreadsheet, new fact sheets will be created, provided there is no name conflict.
